![Tests](https://github.com/NFontrodona/Lazyparser/actions/workflows/run_test.yml/badge.svg)
[![codecov](https://codecov.io/gh/NFontrodona/Lazyparser/graph/badge.svg?token=Q7J5ROFI15)](https://codecov.io/gh/NFontrodona/Lazyparser)


# Lazyparser

## Description

The lazyparser module automatically generates command line interfaces by just decorating a function in a python file.
This module is based on [rich_click](https://github.com/ewels/rich-click).

The lazyparser was written in ``python 3.11 `` with the version 1.8.8 of rich_click.
It is compatible with ``python 3.11`` or higher.

## Documentation

The documentation is available on <https://nfontrodona.github.io/Lazyparser/>.
The documentation was created with [material for mkdocs](https://squidfunk.github.io/mkdocs-material/).
To build the documentation, clone the project repository, and run :

```sh
mkdocs build
```

This will create a folder `site`. This folder will contain a file named ``index.html``. Double click on it to open the documentation with your web browser.


## Installation

To install lazyparser, run :

```sh
pip install lazyparser
```
